<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="项目名称" prop="projectName">
        <el-input
          v-model="queryParams.projectName"
          placeholder="支持模糊查询"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="项目代码" prop="projectCode">
        <el-input
          v-model="queryParams.projectCode"
          placeholder="支持模糊查询"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="上报状态" prop="reportStatus">
        <el-select v-model="queryParams.reportStatus" @change="handleQuery" placeholder="请选择状态" clearable>
          <el-option label="已上报" value="0"></el-option>
          <el-option label="未上报" value="1"></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="年度" prop="reportStatus">
        <el-select v-model="queryParams.yearStatus" @change="handleQuery" placeholder="请选择年度" clearable>
          <el-option label="已上报" value="0"></el-option>
          <el-option label="未上报" value="1"></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="季度" prop="reportStatus">
        <el-select v-model="queryParams.seasonStatus" @change="handleQuery" placeholder="请选择季度" clearable>
          <el-option label="已上报" value="0"></el-option>
          <el-option label="未上报" value="1"></el-option>
        </el-select>
      </el-form-item>
      <el-form-item label="月度" prop="reportStatus">
        <el-select v-model="queryParams.monthStatus" @change="handleQuery" placeholder="请选择月度" clearable>
          <el-option label="已上报" value="0"></el-option>
          <el-option label="未上报" value="1"></el-option>
        </el-select>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
        >查询</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-refresh"
          size="mini"
          @click="handleReset"
        >重置</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="recordList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="ID" align="center" prop="id" />
      <el-table-column label="项目名称" align="center" prop="projectName" />
      <el-table-column label="上报状态" align="center" prop="reportStatus" >
        <template slot-scope="scope">
          {{ scope.row.reportStatus === 0 ? '已上报' : '未上报' }}
        </template>
      </el-table-column>
      <el-table-column label="项目码" align="center" prop="projectColorCode">
        <template slot-scope="scope">
          <el-tag type="success" v-if="scope.row.projectColorCode === 'green'">绿</el-tag>
        </template>
      </el-table-column>
      <el-table-column label="项目代码" align="center" prop="projectCode" />
      <el-table-column label="项目类型" align="center" prop="projectType" />
      <el-table-column label="项目阶段" align="center" prop="projectPhase" />
      <el-table-column label="月度" align="center" prop="monthStatus" >
        <template slot-scope="scope">
          {{ scope.row.monthStatus === 0 ? '已上报' : '未上报' }}
        </template>
      </el-table-column>
      <el-table-column label="季度" align="center" prop="seasonStatus" >
        <template slot-scope="scope">
          {{ scope.row.seasonStatus === 0 ? '已上报' : '未上报' }}
        </template>
      </el-table-column>
      <el-table-column label="年度" align="center" prop="yearStatus" >
        <template slot-scope="scope">
          {{ scope.row.yearStatus === 0 ? '已上报' : '未上报' }}
        </template>
      </el-table-column>
      <el-table-column label="项目状态" align="center" prop="projectStatus" />
      <el-table-column label="投资类别" align="center" prop="investType" >
        <template slot-scope="scope">
          {{
            scope.row.investType === 'enterprise_investment' ? '企业投资' :
              scope.row.investType === 'government_investment' ? '政府投资' :
                scope.row.investType === 'foreign_investment' ? '外商投资' :
                  scope.row.investType === 'abroad_investment' ? '境外投资' :
                    '未知类型'
          }}
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handlePlanRecord(scope.row)"
          >编辑</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.currentPage"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
  </div>
</template>

<script>
import { getList, getManagerFlag } from "@/api/projectPlan/index";

export default {
  name: "Index",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 项目计划记录表格数据
      recordList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        currentPage: 1,
        pageSize: 10,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询项目计划记录列表 */
    getList() {
      this.loading = true;
      getList(this.queryParams).then(response => {
        this.recordList = response.data;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        projectInfoId: null,
        planId: null,
        engineeringInfoId: null,
        planTime: null,
        planTimeFlag: null,
        createTime: null,
        reportStatus: null,
        actualInvest: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加项目计划记录";
    },

    /** 导出按钮操作 */
    handleExport() {
      this.download('plan/record/export', {
        ...this.queryParams
      }, `record_${new Date().getTime()}.xlsx`)
    },
    /** 查看项目计划记录 */
    handlePlanRecord(row) {
      // 获得主管标志
      getManagerFlag(row.id).then(res => {
        this.managerFlag = res.data;
        row.managerFlag = this.managerFlag;
        this.$router.push({
          path: '/projectManage/progressRecord',
          query: {
            data: JSON.stringify(row),
            // id: row.id,
            // projectName: row.projectName,
            // projectCode: row.projectCode,
            // managerFlag: row.managerFlag
          }
        })
      })
    },
    /** 重置按钮 */
    handleReset() {
      this.queryParams = {
        currentPage: 1,
        pageSize: 10,
      }
      this.getList();
    }
  }
};
</script>
